@@ -24,6 +24,7 @@ from great_expectations.cli.v012.cli_messages import (
 from great_expectations.cli.v012.datasource import add_datasource as add_datasource_impl
 from great_expectations.cli.v012.docs import build_docs
 from great_expectations.cli.v012.util import cli_message
+from great_expectations.core.usage_statistics.util import send_usage_message
 from great_expectations.exceptions import (
     DataContextError,
     DatasourceInitializationError,
@@ -101,8 +102,11 @@ def init(target_directory, view, usage_stats):
             context = DataContext.create(
                 target_directory, usage_statistics_enabled=usage_stats
             )
-            toolkit.send_usage_message(
-                data_context=context, event="cli.init.create", success=True
+            send_usage_message(
+                data_context=context,
+                event="cli.init.create",
+                api_version="v2",
+                success=True,
             )
         except DataContextError as e:
             # TODO ensure this is covered by a test
