@@ -81,9 +81,9 @@ def create_expectation_suite(
     :return: a tuple: (success, suite name, profiling_results)
     """
     if generator_asset:
+        # deprecated-v0.13.12
         warnings.warn(
-            "The 'generator_asset' argument will be deprecated and renamed to 'data_asset_name'. "
-            "Please update code accordingly.",
+            "The 'generator_asset' argument is deprecated as of v0.13.12 and will be removed in v0.16. Please use 'data_asset_name' instead.",
             DeprecationWarning,
         )
         data_asset_name = generator_asset
