@@ -70,8 +70,9 @@ class DataAsset:
         batch_markers = kwargs.pop("batch_markers", {})
 
         if "autoinspect_func" in kwargs:
+            # deprecated-v0.10.10
             warnings.warn(
-                "Autoinspect_func is no longer supported; use a profiler instead (migration is easy!).",
+                "Autoinspect_func is deprecated as of v0.10.10 and will be removed in v0.16; use a profiler instead (migration is easy!).",
                 category=DeprecationWarning,
             )
         super().__init__(*args, **kwargs)
@@ -110,9 +111,11 @@ class DataAsset:
         Returns:
             tuple(expectation_suite, validation_results)
         """
+        # deprecated-v0.10.10
         warnings.warn(
-            "The term autoinspect is deprecated and will be removed in a future release. Please use 'profile'\
-        instead."
+            "The term autoinspect is deprecated as of v0.10.10 and will be removed in v0.16. Please use 'profile'\
+        instead.",
+            DeprecationWarning,
         )
         expectation_suite, validation_results = profiler.profile(self)
         return expectation_suite, validation_results
@@ -403,8 +406,9 @@ class DataAsset:
 
     def append_expectation(self, expectation_config):
         """This method is a thin wrapper for ExpectationSuite.append_expectation"""
+        # deprecated-v0.12.0
         warnings.warn(
-            "append_expectation is deprecated, and will be removed in a future release. "
+            "append_expectation is deprecated as of v0.12.0 and will be removed in v0.16. "
             + "Please use ExpectationSuite.add_expectation instead.",
             DeprecationWarning,
         )
@@ -416,8 +420,9 @@ class DataAsset:
         match_type: str = "domain",
     ) -> List[int]:
         """This method is a thin wrapper for ExpectationSuite.find_expectation_indexes"""
+        # deprecated-v0.12.0
         warnings.warn(
-            "find_expectation_indexes is deprecated, and will be removed in a future release. "
+            "find_expectation_indexes is deprecated as of v0.12.0 and will be removed in v0.16. "
             + "Please use ExpectationSuite.find_expectation_indexes instead.",
             DeprecationWarning,
         )
@@ -431,8 +436,9 @@ class DataAsset:
         match_type: str = "domain",
     ) -> List[ExpectationConfiguration]:
         """This method is a thin wrapper for ExpectationSuite.find_expectations()"""
+        # deprecated-v0.12.0
         warnings.warn(
-            "find_expectations is deprecated, and will be removed in a future release. "
+            "find_expectations is deprecated as of v0.12.0 and will be removed in v0.16. "
             + "Please use ExpectationSuite.find_expectation_indexes instead.",
             DeprecationWarning,
         )
@@ -447,8 +453,9 @@ class DataAsset:
         remove_multiple_matches: bool = False,
     ) -> List[ExpectationConfiguration]:
         """This method is a thin wrapper for ExpectationSuite.remove()"""
+        # deprecated-v0.12.0
         warnings.warn(
-            "DataAsset.remove_expectations is deprecated, and will be removed in a future release. "
+            "DataAsset.remove_expectations is deprecated as of v0.12.0 and will be removed in v0.16. "
             + "Please use ExpectationSuite.remove_expectation instead.",
             DeprecationWarning,
         )
@@ -534,8 +541,9 @@ class DataAsset:
         discard_catch_exceptions_kwargs=True,
         suppress_warnings=False,
     ):
+        # deprecated-v0.10.10
         warnings.warn(
-            "get_expectations_config is deprecated, and will be removed in a future release. "
+            "get_expectations_config is deprecated as of v0.10.10 and will be removed in v0.16. "
             + "Please use get_expectation_suite instead.",
             DeprecationWarning,
         )
@@ -794,8 +802,9 @@ class DataAsset:
                 run_id and run_time
             ), "Please provide either a run_id or run_name and/or run_time."
             if isinstance(run_id, str) and not run_name:
+                # deprecated-v0.11.0
                 warnings.warn(
-                    "String run_ids will be deprecated in the future. Please provide a run_id of type "
+                    "String run_ids are deprecated as of v0.11.0 and support will be removed in v0.16. Please provide a run_id of type "
                     "RunIdentifier(run_name=None, run_time=None), or a dictionary containing run_name "
                     "and run_time (both optional). Instead of providing a run_id, you may also provide"
                     "run_name and run_time separately.",
@@ -860,7 +869,7 @@ class DataAsset:
                     handler = data_context._usage_statistics_handler
                     handler.send_usage_message(
                         event="data_asset.validate",
-                        event_payload=handler.anonymizer.anonymize_batch_info(self),
+                        event_payload=handler.anonymizer.anonymize(obj=self),
                         success=False,
                     )
                 return ExpectationValidationResult(success=False)
@@ -1020,7 +1029,7 @@ class DataAsset:
                 handler = data_context._usage_statistics_handler
                 handler.send_usage_message(
                     event="data_asset.validate",
-                    event_payload=handler.anonymizer.anonymize_batch_info(self),
+                    event_payload=handler.anonymizer.anonymize(obj=self),
                     success=False,
                 )
             raise
@@ -1031,7 +1040,7 @@ class DataAsset:
             handler = data_context._usage_statistics_handler
             handler.send_usage_message(
                 event="data_asset.validate",
-                event_payload=handler.anonymizer.anonymize_batch_info(self),
+                event_payload=handler.anonymizer.anonymize(obj=self),
                 success=True,
             )
         return result
