@@ -1434,9 +1434,10 @@ class SparkDFDataset(MetaSparkDFDataset):
         meta=None,
     ):
         deprecation_warning = (
-            "expect_multicolumn_values_to_be_unique is being deprecated. Please use "
-            "expect_select_column_values_to_be_unique_within_record instead."
+            "expect_multicolumn_values_to_be_unique is deprecated as of v0.13.4 and will be removed in v0.16. "
+            "Please use expect_select_column_values_to_be_unique_within_record instead."
         )
+        # deprecated-v0.13.4
         warnings.warn(
             deprecation_warning,
             DeprecationWarning,
