@@ -1,6 +1,7 @@
 from copy import deepcopy
 from typing import Dict, List, Optional, cast
 
+import great_expectations.exceptions as ge_exceptions
 from great_expectations.core.batch import (
     BatchDefinition,
     BatchRequest,
@@ -43,9 +44,10 @@ class ConfiguredAssetSqlDataConnector(DataConnector):
         assets: Optional[Dict[str, dict]] = None,
         batch_spec_passthrough: Optional[dict] = None,
     ):
-        if assets is None:
-            assets = {}
-        self._assets = assets
+        self._assets: dict = {}
+        if assets:
+            for asset_name, config in assets.items():
+                self.add_data_asset(asset_name, config)
 
         super().__init__(
             name=name,
@@ -64,10 +66,37 @@ class ConfiguredAssetSqlDataConnector(DataConnector):
         config: dict,
     ):
         """
-        Add data_asset to DataConnector using data_asset name as key, and data_asset configuration as value.
+        Add data_asset to DataConnector using data_asset name as key, and data_asset config as value.
         """
+        name = self._update_data_asset_name_from_config(name, config)
         self._assets[name] = config
 
+    def _update_data_asset_name_from_config(
+        self, data_asset_name: str, data_asset_config: dict
+    ) -> str:
+
+        data_asset_name_prefix: str = data_asset_config.get(
+            "data_asset_name_prefix", ""
+        )
+        data_asset_name_suffix: str = data_asset_config.get(
+            "data_asset_name_suffix", ""
+        )
+        schema_name: str = data_asset_config.get("schema_name", "")
+        include_schema_name: bool = data_asset_config.get("include_schema_name", True)
+        if schema_name and include_schema_name is False:
+            raise ge_exceptions.DataConnectorError(
+                message=f"{self.__class__.__name__} ran into an error while initializing Asset names. Schema {schema_name} was specified, but 'include_schema_name' flag was set to False."
+            )
+
+        if schema_name:
+            data_asset_name: str = f"{schema_name}.{data_asset_name}"
+
+        data_asset_name: str = (
+            f"{data_asset_name_prefix}{data_asset_name}{data_asset_name_suffix}"
+        )
+
+        return data_asset_name
+
     def _get_batch_identifiers_list_from_data_asset_config(
         self,
         data_asset_name,
@@ -154,7 +183,7 @@ class ConfiguredAssetSqlDataConnector(DataConnector):
         batch_definition_list: List[BatchDefinition] = []
         try:
             sub_cache = self._data_references_cache[batch_request.data_asset_name]
-        except KeyError as e:
+        except KeyError:
             raise KeyError(
                 f"data_asset_name {batch_request.data_asset_name} is not recognized."
             )
@@ -245,13 +274,34 @@ class ConfiguredAssetSqlDataConnector(DataConnector):
             dict built from batch_definition
         """
         data_asset_name: str = batch_definition.data_asset_name
+        table_name: str = self._get_table_name_from_batch_definition(batch_definition)
         return {
             "data_asset_name": data_asset_name,
-            "table_name": data_asset_name,
+            "table_name": table_name,
             "batch_identifiers": batch_definition.batch_identifiers,
             **self.assets[data_asset_name],
         }
 
+    def _get_table_name_from_batch_definition(
+        self, batch_definition: BatchDefinition
+    ) -> str:
+        """
+            Helper method called by _get_batch_identifiers_list_from_data_asset_config() to parse table_name from data_asset_name in cases
+            where schema is included.
+
+            data_asset_name in those cases are [schema].[table_name].
+
+        function will split data_asset_name on [schema]. and return the resulting table_name.
+        """
+        table_name: str = batch_definition.data_asset_name
+        data_asset_dict: dict = self.assets[batch_definition.data_asset_name]
+        if "schema_name" in data_asset_dict:
+            schema_name_str: str = data_asset_dict["schema_name"]
+            if schema_name_str in table_name:
+                table_name = table_name.split(f"{schema_name_str}.")[1]
+
+        return table_name
+
     # Splitter methods for listing partitions
 
     def _split_on_whole_table(
@@ -263,7 +313,6 @@ class ConfiguredAssetSqlDataConnector(DataConnector):
 
         Note: the table_name parameter is a required to keep the signature of this method consistent with other methods.
         """
-
         return sa.select([sa.true()])
 
     def _split_on_column_value(
