@@ -68,10 +68,11 @@ class ExpectColumnValuesToMatchJsonSchema(ColumnMapExpectation):
     # This dictionary contains metadata for display in the public gallery
     library_metadata = {
         "maturity": "production",
-        "package": "great_expectations",
         "tags": ["core expectation", "column map expectation"],
         "contributors": ["@great_expectations"],
         "requirements": [],
+        "has_full_test_suite": True,
+        "manually_reviewed_code": True,
     }
 
     map_metric = "column_values.match_json_schema"
@@ -95,11 +96,9 @@ class ExpectColumnValuesToMatchJsonSchema(ColumnMapExpectation):
 
     def validate_configuration(
         self, configuration: Optional[ExpectationConfiguration]
-    ) -> bool:
+    ) -> None:
         super().validate_configuration(configuration)
 
-        return True
-
     @classmethod
     def _atomic_prescriptive_template(
         cls,
@@ -123,7 +122,7 @@ class ExpectColumnValuesToMatchJsonSchema(ColumnMapExpectation):
             "column": {"schema": {"type": "string"}, "value": params.get("column")},
             "mostly": {"schema": {"type": "number"}, "value": params.get("mostly")},
             "mostly_pct": {
-                "schema": {"type": "number"},
+                "schema": {"type": "string"},
                 "value": params.get("mostly_pct"),
             },
             "json_schema": {
