@@ -73,12 +73,13 @@ class ExpectColumnValuesToMatchRegexList(ColumnMapExpectation):
 
     library_metadata = {
         "maturity": "production",
-        "package": "great_expectations",
         "tags": ["core expectation", "column map expectation"],
         "contributors": [
             "@great_expectations",
         ],
         "requirements": [],
+        "has_full_test_suite": True,
+        "manually_reviewed_code": True,
     }
 
     map_metric = "column_values.match_regex_list"
@@ -103,7 +104,7 @@ class ExpectColumnValuesToMatchRegexList(ColumnMapExpectation):
 
     def validate_configuration(
         self, configuration: Optional[ExpectationConfiguration]
-    ) -> bool:
+    ) -> None:
         super().validate_configuration(configuration)
         if configuration is None:
             configuration = self.configuration
@@ -124,7 +125,6 @@ class ExpectColumnValuesToMatchRegexList(ColumnMapExpectation):
                 ), 'Evaluation Parameter dict for regex_list kwarg must have "$PARAMETER" key.'
         except AssertionError as e:
             raise InvalidExpectationConfigurationError(str(e))
-        return True
 
     @classmethod
     def _atomic_prescriptive_template(
@@ -159,6 +159,10 @@ class ExpectColumnValuesToMatchRegexList(ColumnMapExpectation):
                 "value": params.get("regex_list"),
             },
             "mostly": {"schema": {"type": "number"}, "value": params.get("mostly")},
+            "mostly_pct": {
+                "schema": {"type": "string"},
+                "value": params.get("mostly_pct"),
+            },
             "match_on": {"schema": {"type": "string"}, "value": params.get("match_on")},
             "row_condition": {
                 "schema": {"type": "string"},
@@ -191,7 +195,7 @@ class ExpectColumnValuesToMatchRegexList(ColumnMapExpectation):
             )
 
         if params["mostly"] is not None:
-            params["mostly_pct"] = num_to_str(
+            params_with_json_schema["mostly_pct"]["value"] = num_to_str(
                 params["mostly"] * 100, precision=15, no_scientific=True
             )
             # params["mostly_pct"] = "{:.14f}".format(params["mostly"]*100).rstrip("0").rstrip(".")
