@@ -4,6 +4,7 @@ from typing import Any, Dict, List, Optional
 
 import numpy as np
 from dateutil.parser import parse
+from packaging import version
 
 from great_expectations.execution_engine.util import check_sql_engine_dialect
 from great_expectations.util import get_sqlalchemy_inspector
@@ -75,8 +76,10 @@ except ImportError:
     try:
         import pybigquery.sqlalchemy_bigquery as sqla_bigquery
 
+        # deprecated-v0.14.7
         warnings.warn(
-            "The pybigquery package is obsolete, please use sqlalchemy-bigquery",
+            "The pybigquery package is obsolete and its usage within Great Expectations is deprecated as of v0.14.7. "
+            "As support will be removed in v0.17, please transition to sqlalchemy-bigquery",
             DeprecationWarning,
         )
         _BIGQUERY_MODULE_NAME = "pybigquery.sqlalchemy_bigquery"
@@ -207,6 +210,25 @@ def get_dialect_regex_expression(column, regex, dialect, positive=True):
     except (AttributeError, TypeError):
         pass
 
+    try:
+        # sqlite
+        # regex_match for sqlite introduced in sqlalchemy v1.4
+        if issubclass(dialect.dialect, sa.dialects.sqlite.dialect) and version.parse(
+            sa.__version__
+        ) >= version.parse("1.4"):
+            if positive:
+                return column.regexp_match(literal(regex))
+            else:
+                return sa.not_(column.regexp_match(literal(regex)))
+        else:
+            logger.debug(
+                "regex_match is only enabled for sqlite when SQLAlchemy version is >= 1.4",
+                exc_info=True,
+            )
+            pass
+    except AttributeError:
+        pass
+
     return None
 
 
