@@ -1,3 +1,6 @@
+import enum
+from dataclasses import dataclass
+
 from pyparsing import (
     CaselessLiteral,
     Combine,
@@ -10,7 +13,7 @@ from pyparsing import (
     alphas,
 )
 
-from great_expectations.exceptions import GreatExpectationsError
+import great_expectations.exceptions as ge_exceptions
 
 try:
     import pyspark.sql.functions as F
@@ -52,10 +55,40 @@ condition = (column_name + not_null).setParseAction(_set_notnull) ^ (
 )
 
 
-class ConditionParserError(GreatExpectationsError):
+class ConditionParserError(ge_exceptions.GreatExpectationsError):
     pass
 
 
+class RowConditionParserType(enum.Enum):
+    """Type of condition or parser to be used to interpret a RowCondition
+
+    Note that many of these are forward looking and are not yet implemented.
+    In the future `GE` can replace the `great_expectations__experimental__`
+    name for the condition_parser and this enum can be used internally
+    instead of strings for the condition_parser user input.
+    """
+
+    GE = "ge"  # GE intermediate language
+    SPARK = "spark"  # Spark pyspark.sql.Column type
+    SPARK_SQL = "spark_sql"  # String type
+    PANDAS = "pandas"  # pandas parser for pandas DataFrame.query()
+    PYTHON = "python"  # python parser for DataFrame.query()
+    SQL = "sql"  # Selectable type
+
+
+@dataclass
+class RowCondition:
+    """Condition that can be used to filter rows in a data set.
+
+    Attributes:
+        condition: String of the condition
+        condition_type: Format of the condition e.g. for parsing
+    """
+
+    condition: str
+    condition_type: RowConditionParserType
+
+
 def _parse_great_expectations_condition(row_condition: str):
     try:
         return condition.parseString(row_condition)
