@@ -403,15 +403,11 @@ class BasicSuiteBuilderProfiler(BasicDatasetProfilerBase):
             )
             type = cls._get_column_type_with_caching(dataset, column, column_cache)
 
-            if (
-                cardinality
-                in [
-                    ProfilerCardinality.MANY,
-                    ProfilerCardinality.VERY_MANY,
-                    ProfilerCardinality.UNIQUE,
-                ]
-                and type in [ProfilerDataType.INT, ProfilerDataType.FLOAT]
-            ):
+            if cardinality in [
+                ProfilerCardinality.MANY,
+                ProfilerCardinality.VERY_MANY,
+                ProfilerCardinality.UNIQUE,
+            ] and type in [ProfilerDataType.INT, ProfilerDataType.FLOAT]:
                 return column
 
         return None
@@ -427,15 +423,11 @@ class BasicSuiteBuilderProfiler(BasicDatasetProfilerBase):
             )
             type = cls._get_column_type_with_caching(dataset, column, column_cache)
 
-            if (
-                cardinality
-                in [
-                    ProfilerCardinality.MANY,
-                    ProfilerCardinality.VERY_MANY,
-                    ProfilerCardinality.UNIQUE,
-                ]
-                and type in [ProfilerDataType.STRING, ProfilerDataType.UNKNOWN]
-            ):
+            if cardinality in [
+                ProfilerCardinality.MANY,
+                ProfilerCardinality.VERY_MANY,
+                ProfilerCardinality.UNIQUE,
+            ] and type in [ProfilerDataType.STRING, ProfilerDataType.UNKNOWN]:
                 return column
 
         return None
@@ -453,15 +445,11 @@ class BasicSuiteBuilderProfiler(BasicDatasetProfilerBase):
             )
             type = cls._get_column_type_with_caching(dataset, column, column_cache)
 
-            if (
-                cardinality
-                in [
-                    ProfilerCardinality.MANY,
-                    ProfilerCardinality.VERY_MANY,
-                    ProfilerCardinality.UNIQUE,
-                ]
-                and type in [ProfilerDataType.DATETIME]
-            ):
+            if cardinality in [
+                ProfilerCardinality.MANY,
+                ProfilerCardinality.VERY_MANY,
+                ProfilerCardinality.UNIQUE,
+            ] and type in [ProfilerDataType.DATETIME]:
                 return column
 
         return None
