@@ -7,16 +7,9 @@ from great_expectations.rule_based_profiler.domain_builder.table_domain_builder
 from great_expectations.rule_based_profiler.domain_builder.column_domain_builder import (  # isort:skip
     ColumnDomainBuilder,
 )
-from great_expectations.rule_based_profiler.domain_builder.simple_column_suffix_domain_builder import (  # isort:skip
-    SimpleColumnSuffixDomainBuilder,
-)
 from great_expectations.rule_based_profiler.domain_builder.categorical_column_domain_builder import (  # isort:skip
     CategoricalColumnDomainBuilder,
 )
 from great_expectations.rule_based_profiler.domain_builder.map_metric_column_domain_builder import (
     MapMetricColumnDomainBuilder,
 )
-
-from great_expectations.rule_based_profiler.domain_builder.simple_semantic_type_domain_builder import (  # isort:skip
-    SimpleSemanticTypeColumnDomainBuilder,
-)
