@@ -37,7 +37,7 @@ def get_validator(
     *,
     data_context: Optional["DataContext"] = None,  # noqa: F821
     batch_list: Optional[List[Batch]] = None,
-    batch_request: Optional[Union[BatchRequest, RuntimeBatchRequest, dict, str]] = None,
+    batch_request: Optional[Union[str, BatchRequest, RuntimeBatchRequest, dict]] = None,
     domain: Optional[Domain] = None,
     variables: Optional[ParameterContainer] = None,
     parameters: Optional[Dict[str, ParameterContainer]] = None,
@@ -92,7 +92,7 @@ def get_validator(
 def get_batch_ids(
     data_context: Optional["DataContext"] = None,  # noqa: F821
     batch_list: Optional[List[Batch]] = None,
-    batch_request: Optional[Union[BatchRequest, RuntimeBatchRequest, dict, str]] = None,
+    batch_request: Optional[Union[str, BatchRequest, RuntimeBatchRequest, dict]] = None,
     domain: Optional[Domain] = None,
     variables: Optional[ParameterContainer] = None,
     parameters: Optional[Dict[str, ParameterContainer]] = None,
@@ -124,7 +124,7 @@ def get_batch_ids(
 
 
 def build_batch_request(
-    batch_request: Optional[Union[BatchRequest, RuntimeBatchRequest, dict, str]] = None,
+    batch_request: Optional[Union[str, BatchRequest, RuntimeBatchRequest, dict]] = None,
     domain: Optional[Domain] = None,
     variables: Optional[ParameterContainer] = None,
     parameters: Optional[Dict[str, ParameterContainer]] = None,
@@ -528,8 +528,8 @@ def _compute_bootstrap_quantiles_point_estimate_custom_bias_corrected_method(
     lower_quantile_pct: float = false_positive_rate / 2
     upper_quantile_pct: float = 1.0 - false_positive_rate / 2
 
-    sample_lower_quantile: Number = np.quantile(metric_values, q=lower_quantile_pct)
-    sample_upper_quantile: Number = np.quantile(metric_values, q=upper_quantile_pct)
+    sample_lower_quantile: np.ndarray = np.quantile(metric_values, q=lower_quantile_pct)
+    sample_upper_quantile: np.ndarray = np.quantile(metric_values, q=upper_quantile_pct)
 
     if random_seed:
         random_state: np.random.Generator = np.random.Generator(
@@ -548,9 +548,9 @@ def _compute_bootstrap_quantiles_point_estimate_custom_bias_corrected_method(
         q=lower_quantile_pct,
         axis=1,
     )
-    bootstrap_lower_quantile_point_estimate: Number = np.mean(bootstrap_lower_quantiles)
-    bootstrap_lower_quantile_standard_error: Number = np.std(bootstrap_lower_quantiles)
-    bootstrap_lower_quantile_bias: Number = (
+    bootstrap_lower_quantile_point_estimate: float = np.mean(bootstrap_lower_quantiles)
+    bootstrap_lower_quantile_standard_error: float = np.std(bootstrap_lower_quantiles)
+    bootstrap_lower_quantile_bias: float = (
         bootstrap_lower_quantile_point_estimate - sample_lower_quantile
     )
 
@@ -573,9 +573,13 @@ def _compute_bootstrap_quantiles_point_estimate_custom_bias_corrected_method(
         q=upper_quantile_pct,
         axis=1,
     )
-    bootstrap_upper_quantile_point_estimate: Number = np.mean(bootstrap_upper_quantiles)
-    bootstrap_upper_quantile_standard_error: Number = np.std(bootstrap_upper_quantiles)
-    bootstrap_upper_quantile_bias: Number = (
+    bootstrap_upper_quantile_point_estimate: np.ndarray = np.mean(
+        bootstrap_upper_quantiles
+    )
+    bootstrap_upper_quantile_standard_error: np.ndarray = np.std(
+        bootstrap_upper_quantiles
+    )
+    bootstrap_upper_quantile_bias: float = (
         bootstrap_upper_quantile_point_estimate - sample_upper_quantile
     )
 
