@@ -2,13 +2,15 @@ import copy
 import itertools
 from abc import ABC, abstractmethod
 from dataclasses import asdict, dataclass, make_dataclass
-from typing import Any, Callable, Dict, List, Optional, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Set, Tuple, Union
 
 import numpy as np
 
 import great_expectations.exceptions as ge_exceptions
 from great_expectations.core.batch import Batch, BatchRequest, RuntimeBatchRequest
 from great_expectations.core.util import convert_to_json_serializable
+from great_expectations.data_context.util import instantiate_class_from_config
+from great_expectations.rule_based_profiler.config import ParameterBuilderConfig
 from great_expectations.rule_based_profiler.helpers.util import (
     build_metric_domain_kwargs,
 )
@@ -22,11 +24,13 @@ from great_expectations.rule_based_profiler.helpers.util import (
     get_validator as get_validator_using_batch_list_or_batch_request,
 )
 from great_expectations.rule_based_profiler.types import (
+    PARAMETER_KEY,
     Attributes,
     Builder,
     Domain,
     ParameterContainer,
     build_parameter_container,
+    get_fully_qualified_parameter_names,
 )
 from great_expectations.types import SerializableDictDot
 from great_expectations.validator.metric_configuration import MetricConfiguration
@@ -87,24 +91,36 @@ class ParameterBuilder(Builder, ABC):
         ```
     """
 
+    exclude_field_names: Set[str] = Builder.exclude_field_names | {
+        "evaluation_parameter_builders",
+    }
+
     def __init__(
         self,
         name: str,
-        batch_list: Optional[List[Batch]] = None,
-        batch_request: Optional[Union[BatchRequest, RuntimeBatchRequest, dict]] = None,
+        evaluation_parameter_builder_configs: Optional[
+            List[ParameterBuilderConfig]
+        ] = None,
         json_serialize: Union[str, bool] = True,
+        batch_list: Optional[List[Batch]] = None,
+        batch_request: Optional[
+            Union[str, BatchRequest, RuntimeBatchRequest, dict]
+        ] = None,
         data_context: Optional["DataContext"] = None,  # noqa: F821
     ):
         """
-        The ParameterBuilder will build parameters for the active domain from the rule.
+        The ParameterBuilder will build ParameterNode objects for a Domain from the Rule.
 
         Args:
             name: the name of this parameter builder -- this is user-specified parameter name (from configuration);
             it is not the fully-qualified parameter name; a fully-qualified parameter name must start with "$parameter."
             and may contain one or more subsequent parts (e.g., "$parameter.<my_param_from_config>.<metric_name>").
+            evaluation_parameter_builder_configs: ParameterBuilder configurations, executing and making whose respective
+            ParameterBuilder objects' outputs available (as fully-qualified parameter names) is pre-requisite.
+            These "ParameterBuilder" configurations help build parameters needed for this "ParameterBuilder".
+            json_serialize: If True (default), convert computed value to JSON prior to saving results.
             batch_list: explicitly passed Batch objects for parameter computation (take precedence over batch_request).
             batch_request: specified in ParameterBuilder configuration to get Batch objects for parameter computation.
-            json_serialize: If True (default), convert computed value to JSON prior to saving results.
             data_context: DataContext
         """
         super().__init__(
@@ -115,6 +131,11 @@ class ParameterBuilder(Builder, ABC):
 
         self._name = name
 
+        self._evaluation_parameter_builders = init_rule_parameter_builders(
+            parameter_builder_configs=evaluation_parameter_builder_configs,
+            data_context=self._data_context,
+        )
+
         self._json_serialize = json_serialize
 
     def build_parameters(
@@ -126,12 +147,19 @@ class ParameterBuilder(Builder, ABC):
         parameter_computation_impl: Optional[Callable] = None,
         json_serialize: Optional[bool] = None,
     ) -> None:
-        computed_parameter_value: Any
-        parameter_computation_details: dict
+        resolve_evaluation_dependencies(
+            parameter_builder=self,
+            parameter_container=parameter_container,
+            domain=domain,
+            variables=variables,
+            parameters=parameters,
+        )
 
         if parameter_computation_impl is None:
             parameter_computation_impl = self._build_parameters
 
+        computed_parameter_value: Any
+        parameter_computation_details: dict
         (
             computed_parameter_value,
             parameter_computation_details,
@@ -174,6 +202,12 @@ class ParameterBuilder(Builder, ABC):
     def name(self) -> str:
         return self._name
 
+    @property
+    def evaluation_parameter_builders(
+        self,
+    ) -> Optional[List["ParameterBuilder"]]:  # noqa: F821
+        return self._evaluation_parameter_builders
+
     @property
     def json_serialize(self) -> Union[str, bool]:
         return self._json_serialize
@@ -278,7 +312,7 @@ class ParameterBuilder(Builder, ABC):
         Then, all "MetricConfiguration" objects, collected into list as container, are resolved simultaneously.
         """
 
-        # First: Gather "metric_domain_kwargs" (corresponding to "batch_ids").
+        # Step-1: Gather "metric_domain_kwargs" (corresponding to "batch_ids").
 
         domain_kwargs: dict = build_metric_domain_kwargs(
             batch_id=None,
@@ -302,7 +336,7 @@ class ParameterBuilder(Builder, ABC):
             for batch_id in batch_ids
         ]
 
-        # Second: Gather "metric_value_kwargs" (caller may require same metric computed for multiple arguments).
+        # Step-2: Gather "metric_value_kwargs" (caller may require same metric computed for multiple arguments).
 
         if not isinstance(metric_value_kwargs, list):
             metric_value_kwargs = [metric_value_kwargs]
@@ -320,7 +354,7 @@ class ParameterBuilder(Builder, ABC):
             for value_kwargs_cursor in metric_value_kwargs
         ]
 
-        # Third: Generate "MetricConfiguration" directives for all "metric_domain_kwargs" / "metric_value_kwargs" pairs.
+        # Step-3: Generate "MetricConfiguration" directives for all "metric_domain_kwargs" / "metric_value_kwargs" pairs.
 
         domain_kwargs_cursor: dict
         kwargs_combinations: List[List[dict]] = [
@@ -340,7 +374,7 @@ class ParameterBuilder(Builder, ABC):
             for kwargs_pair_cursor in kwargs_combinations
         ]
 
-        # Fourth: Resolve all metrics in one operation simultaneously.
+        # Step-4: Resolve all metrics in one operation simultaneously.
 
         # The Validator object used for metric calculation purposes.
         validator: "Validator" = self.get_validator(  # noqa: F821
@@ -353,7 +387,7 @@ class ParameterBuilder(Builder, ABC):
             metric_configurations=metrics_to_resolve
         )
 
-        # Fifth: Map resolved metrics to their attributes for identification and recovery by receiver.
+        # Step-5: Map resolved metrics to their attributes for identification and recovery by receiver.
 
         metric_configuration: MetricConfiguration
         attributed_resolved_metrics_map: Dict[str, AttributedResolvedMetrics] = {}
@@ -379,12 +413,13 @@ class ParameterBuilder(Builder, ABC):
                 raise ge_exceptions.ProfilerExecutionError(
                     f"{metric_configuration.id[0]} was not found in the resolved Metrics for ParameterBuilder."
                 )
+
             attributed_resolved_metrics.add_resolved_metric(value=resolved_metric_value)
 
         metric_attributes_id: str
         metric_values: AttributedResolvedMetrics
 
-        # Sixth: Leverage Numpy Array capabilities for subsequent operations on results of computed/resolved metrics.
+        # Step-6: Leverage Numpy Array capabilities for subsequent operations on results of computed/resolved metrics.
 
         attributed_resolved_metrics_map = {
             metric_attributes_id: AttributedResolvedMetrics(
@@ -394,7 +429,7 @@ class ParameterBuilder(Builder, ABC):
             for metric_attributes_id, metric_values in attributed_resolved_metrics_map.items()
         }
 
-        # Seventh: Convert scalar metric values to vectors to enable uniformity of processing in subsequent operations.
+        # Step-7: Convert scalar metric values to vectors to enable uniformity of processing in subsequent operations.
 
         idx: int
         for (
@@ -408,7 +443,7 @@ class ParameterBuilder(Builder, ABC):
                 metric_values.metric_values = np.array(metric_values.metric_values)
                 attributed_resolved_metrics_map[metric_attributes_id] = metric_values
 
-        # Eighth: Apply numeric/hygiene directives (e.g., "enforce_numeric_metric", "replace_nan_with_zero") to results.
+        # Step-8: Apply numeric/hygiene directives (e.g., "enforce_numeric_metric", "replace_nan_with_zero") to results.
         for (
             metric_attributes_id,
             metric_values,
@@ -423,7 +458,7 @@ class ParameterBuilder(Builder, ABC):
                 parameters=parameters,
             )
 
-        # Ninth: Compose and return result to receiver (apply simplifications to cases of single "metric_value_kwargs").
+        # Step-9: Compose and return result to receiver (apply simplifications to cases of single "metric_value_kwargs").
         return MetricComputationResult(
             list(attributed_resolved_metrics_map.values()),
             details={
@@ -514,6 +549,103 @@ class ParameterBuilder(Builder, ABC):
 """
                         )
 
-                    np.nan_to_num(metric_value_vector, copy=True, nan=0.0)
+                    np.nan_to_num(metric_value_vector, copy=False, nan=0.0)
 
         return metric_values
+
+
+def init_rule_parameter_builders(
+    parameter_builder_configs: Optional[List[dict]] = None,
+    data_context: Optional["DataContext"] = None,  # noqa: F821
+) -> Optional[List["ParameterBuilder"]]:  # noqa: F821
+    if parameter_builder_configs is None:
+        return None
+
+    return [
+        init_parameter_builder(
+            parameter_builder_config=parameter_builder_config,
+            data_context=data_context,
+        )
+        for parameter_builder_config in parameter_builder_configs
+    ]
+
+
+def init_parameter_builder(
+    parameter_builder_config: Union["ParameterBuilderConfig", dict],  # noqa: F821
+    data_context: Optional["DataContext"] = None,  # noqa: F821
+) -> "ParameterBuilder":  # noqa: F821
+    if not isinstance(parameter_builder_config, dict):
+        parameter_builder_config = parameter_builder_config.to_dict()
+
+    parameter_builder: "ParameterBuilder" = instantiate_class_from_config(  # noqa: F821
+        config=parameter_builder_config,
+        runtime_environment={"data_context": data_context},
+        config_defaults={
+            "module_name": "great_expectations.rule_based_profiler.parameter_builder"
+        },
+    )
+    return parameter_builder
+
+
+def resolve_evaluation_dependencies(
+    parameter_builder: "ParameterBuilder",  # noqa: F821
+    parameter_container: ParameterContainer,
+    domain: Domain,
+    variables: Optional[ParameterContainer] = None,
+    parameters: Optional[Dict[str, ParameterContainer]] = None,
+) -> None:
+    """
+    This method computes ("resolves") pre-requisite ("evaluation") dependencies (i.e., results of executing other
+    "ParameterBuilder" objects), whose output(s) are needed by specified "ParameterBuilder" object to fulfill its goals.
+    """
+
+    # Step-1: Check if any "evaluation_parameter_builders" are configured for specified "ParameterBuilder" object.
+    evaluation_parameter_builders: List[
+        "ParameterBuilder"  # noqa: F821
+    ] = parameter_builder.evaluation_parameter_builders
+    if not evaluation_parameter_builders:
+        return
+
+    # Step-2: Obtain all fully-qualified parameter names ("variables" and "parameter" keys) in namespace of "Domain"
+    # (fully-qualified parameter names are stored in "ParameterNode" objects of "ParameterContainer" of "Domain"
+    # whenever "ParameterBuilder.build_parameters()" is executed for "ParameterBuilder.fully_qualified_parameter_name").
+    fully_qualified_parameter_names: List[str] = get_fully_qualified_parameter_names(
+        domain=domain,
+        variables=variables,
+        parameters=parameters,
+    )
+
+    # Step-3: Check for presence of fully-qualified parameter names of "ParameterBuilder" objects, obtained by iterating
+    # over evaluation dependencies.  "Execute ParameterBuilder.build_parameters()" if absent from "Domain" scoped list.
+    evaluation_parameter_builder: "ParameterBuilder"  # noqa: F821
+    for evaluation_parameter_builder in evaluation_parameter_builders:
+        fully_qualified_evaluation_parameter_builder_name: str = (
+            f"{PARAMETER_KEY}{evaluation_parameter_builder.name}"
+        )
+
+        if (
+            fully_qualified_evaluation_parameter_builder_name
+            not in fully_qualified_parameter_names
+        ):
+            evaluation_parameter_builder.set_batch_list_or_batch_request(
+                batch_list=parameter_builder.batch_list,
+                batch_request=parameter_builder.batch_request,
+                force_batch_data=False,
+            )
+
+            evaluation_parameter_builder.build_parameters(
+                parameter_container=parameter_container,
+                domain=domain,
+                variables=variables,
+                parameters=parameters,
+            )
+
+            # Step-4: Any "ParameterBuilder" object, including members of "evaluation_parameter_builders" list may be
+            # configured with its own "evaluation_parameter_builders" list.  Recursive call handles such situations.
+            resolve_evaluation_dependencies(
+                parameter_builder=evaluation_parameter_builder,
+                parameter_container=parameter_container,
+                domain=domain,
+                variables=variables,
+                parameters=parameters,
+            )
