@@ -1,19 +1,18 @@
 from .attributes import Attributes  # isort:skip
 from .builder import Builder  # isort:skip
-
 from .domain import (  # isort:skip
     Domain,
     SemanticDomainTypes,
     InferredSemanticDomainType,
 )
 from .parameter_container import (  # isort:skip
-    DOMAIN_KWARGS_PARAMETER_NAME,
-    PARAMETER_NAME_ROOT_FOR_VARIABLES,
-    PARAMETER_NAME_ROOT_FOR_PARAMETERS,
-    VARIABLES_PREFIX,
-    VARIABLES_KEY,
-    PARAMETER_PREFIX,
+    DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
+    FULLY_QUALIFIED_PARAMETER_NAME_SEPARATOR_CHARACTER,
+    FULLY_QUALIFIED_PARAMETER_NAME_VALUE_KEY,
+    FULLY_QUALIFIED_PARAMETER_NAME_METADATA_KEY,
     PARAMETER_KEY,
+    VARIABLES_KEY,
+    VARIABLES_PREFIX,
     ParameterNode,
     ParameterContainer,
     build_parameter_container,
