@@ -22,6 +22,47 @@ from tests.core.usage_statistics.util import (
 from tests.test_utils import create_files_in_directory, set_directory
 
 
+@pytest.fixture
+def test_connectable_postgresql_db(sa, test_backends, test_df):
+    """Populates a postgres DB with a `test_df` table in the `connection_test` schema to test DataConnectors against"""
+
+    if "postgresql" not in test_backends:
+        pytest.skip("skipping fixture because postgresql not selected")
+
+    import sqlalchemy as sa
+
+    url = sa.engine.url.URL(
+        drivername="postgresql",
+        username="postgres",
+        password="",
+        host=os.getenv("GE_TEST_LOCAL_DB_HOSTNAME", "localhost"),
+        port="5432",
+        database="test_ci",
+    )
+    engine = sa.create_engine(url)
+
+    schema_check_results = engine.execute(
+        "SELECT schema_name FROM information_schema.schemata WHERE schema_name = 'connection_test';"
+    ).fetchall()
+    if len(schema_check_results) == 0:
+        engine.execute("CREATE SCHEMA connection_test;")
+
+    table_check_results = engine.execute(
+        """
+SELECT EXISTS (
+   SELECT FROM information_schema.tables
+   WHERE  table_schema = 'connection_test'
+   AND    table_name   = 'test_df'
+);
+"""
+    ).fetchall()
+    if table_check_results != [(True,)]:
+        test_df.to_sql(name="test_df", con=engine, index=True, schema="connection_test")
+
+    # Return a connection string to this newly-created db
+    return engine
+
+
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
@@ -242,6 +283,9 @@ def test_checkpoint_store_with_filesystem_store_backend(
     assert not usage_stats_invalid_messages_exist(messages=caplog.messages)
 
 
+@pytest.mark.filterwarnings(
+    "ignore:String run_ids are deprecated*:DeprecationWarning:great_expectations.data_context.types.resource_identifiers"
+)
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
@@ -738,6 +782,9 @@ def test_golden_path_sql_datasource_configuration(
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
+@pytest.mark.filterwarnings(
+    "ignore:get_batch is deprecated*:DeprecationWarning:great_expectations.data_context.data_context"
+)
 def test_golden_path_inferred_asset_pandas_datasource_configuration(
     mock_emit, caplog, empty_data_context_stats_enabled, test_df, tmp_path_factory
 ):
@@ -927,6 +974,9 @@ def test_golden_path_inferred_asset_pandas_datasource_configuration(
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
+@pytest.mark.filterwarnings(
+    "ignore:get_batch is deprecated*:DeprecationWarning:great_expectations.data_context.data_context"
+)
 def test_golden_path_configured_asset_pandas_datasource_configuration(
     mock_emit, caplog, empty_data_context_stats_enabled, test_df, tmp_path_factory
 ):
