@@ -15,6 +15,7 @@ from great_expectations.data_context.util import instantiate_class_from_config
 from great_expectations.datasource.data_connector import (
     ConfiguredAssetAzureDataConnector,
 )
+from great_expectations.execution_engine import PandasExecutionEngine
 
 yaml = YAML()
 
@@ -240,6 +241,7 @@ def test_instantiation_with_account_url_and_credential(
     my_data_connector = ConfiguredAssetAzureDataConnector(
         name="my_data_connector",
         datasource_name="FAKE_DATASOURCE_NAME",
+        execution_engine=PandasExecutionEngine(),
         default_regex={
             "pattern": "alpha-(.*)\\.csv",
             "group_names": ["index"],
@@ -272,6 +274,7 @@ def test_instantiation_with_conn_str_and_credential(
     my_data_connector = ConfiguredAssetAzureDataConnector(
         name="my_data_connector",
         datasource_name="FAKE_DATASOURCE_NAME",
+        execution_engine=PandasExecutionEngine(),
         default_regex={
             "pattern": "alpha-(.*)\\.csv",
             "group_names": ["index"],
@@ -299,6 +302,7 @@ def test_instantiation_with_valid_account_url_assigns_account_name(mock_azure_co
     my_data_connector = ConfiguredAssetAzureDataConnector(
         name="my_data_connector",
         datasource_name="FAKE_DATASOURCE_NAME",
+        execution_engine=PandasExecutionEngine(),
         default_regex={
             "pattern": "alpha-(.*)\\.csv",
             "group_names": ["index"],
@@ -321,6 +325,7 @@ def test_instantiation_with_valid_conn_str_assigns_account_name(mock_azure_conn)
     my_data_connector = ConfiguredAssetAzureDataConnector(
         name="my_data_connector",
         datasource_name="FAKE_DATASOURCE_NAME",
+        execution_engine=PandasExecutionEngine(),
         default_regex={
             "pattern": "alpha-(.*)\\.csv",
             "group_names": ["index"],
@@ -347,6 +352,7 @@ def test_instantiation_with_multiple_auth_methods_raises_error(
         ConfiguredAssetAzureDataConnector(
             name="my_data_connector",
             datasource_name="FAKE_DATASOURCE_NAME",
+            execution_engine=PandasExecutionEngine(),
             default_regex={
                 "pattern": "alpha-(.*)\\.csv",
                 "group_names": ["index"],
@@ -374,6 +380,7 @@ def test_instantiation_with_improperly_formatted_auth_keys_in_azure_options_rais
         ConfiguredAssetAzureDataConnector(
             name="my_data_connector",
             datasource_name="FAKE_DATASOURCE_NAME",
+            execution_engine=PandasExecutionEngine(),
             default_regex={
                 "pattern": "alpha-(.*)\\.csv",
                 "group_names": ["index"],
@@ -390,6 +397,7 @@ def test_instantiation_with_improperly_formatted_auth_keys_in_azure_options_rais
         ConfiguredAssetAzureDataConnector(
             name="my_data_connector",
             datasource_name="FAKE_DATASOURCE_NAME",
+            execution_engine=PandasExecutionEngine(),
             default_regex={
                 "pattern": "alpha-(.*)\\.csv",
                 "group_names": ["index"],
@@ -438,6 +446,9 @@ def test_instantiation_with_test_yaml_config(
             account_url: my_account_url.blob.core.windows.net
             credential: my_credential
     """,
+        runtime_environment={
+            "execution_engine": PandasExecutionEngine(),
+        },
         return_mode="report_object",
     )
 
@@ -477,6 +488,9 @@ def test_instantiation_with_test_yaml_config_emits_proper_payload(
             account_url: my_account_url.blob.core.windows.net
             credential: my_credential
     """,
+        runtime_environment={
+            "execution_engine": PandasExecutionEngine(),
+        },
         return_mode="report_object",
     )
     assert mock_emit.call_count == 1
@@ -532,6 +546,9 @@ def test_instantiation_from_a_config_with_nonmatching_regex_creates_unmatched_re
             account_url: my_account_url.blob.core.windows.net
             credential: my_credential
     """,
+        runtime_environment={
+            "execution_engine": PandasExecutionEngine(),
+        },
         return_mode="report_object",
     )
 
@@ -569,6 +586,7 @@ def test_get_batch_definition_list_from_batch_request_with_nonexistent_datasourc
     my_data_connector = ConfiguredAssetAzureDataConnector(
         name="my_data_connector",
         datasource_name="FAKE_DATASOURCE_NAME",
+        execution_engine=PandasExecutionEngine(),
         default_regex={
             "pattern": "alpha-(.*)\\.csv",
             "group_names": ["index"],
@@ -609,8 +627,6 @@ def test_get_definition_list_from_batch_request_with_empty_args_raises_error(
         f"""
            class_name: ConfiguredAssetAzureDataConnector
            datasource_name: test_environment
-           execution_engine:
-               class_name: PandasExecutionEngine
            container: my_container
            name_starts_with: ""
            assets:
@@ -647,7 +663,7 @@ def test_get_definition_list_from_batch_request_with_empty_args_raises_error(
             config=my_data_connector_yaml,
             runtime_environment={
                 "name": "general_azure_data_connector",
-                "datasource_name": "test_environment",
+                "execution_engine": PandasExecutionEngine(),
             },
             config_defaults={
                 "module_name": "great_expectations.datasource.data_connector"
@@ -657,6 +673,7 @@ def test_get_definition_list_from_batch_request_with_empty_args_raises_error(
 
     # Raises error in `FilePathDataConnector.get_batch_definition_list_from_batch_request()` due to missing a `batch_request` arg
     with pytest.raises(TypeError):
+        # noinspection PyArgumentList
         my_data_connector.get_batch_definition_list_from_batch_request()
 
 
@@ -676,8 +693,6 @@ def test_get_definition_list_from_batch_request_with_unnamed_data_asset_name_rai
         f"""
            class_name: ConfiguredAssetAzureDataConnector
            datasource_name: test_environment
-           execution_engine:
-               class_name: PandasExecutionEngine
            container: my_container
            name_starts_with: ""
            assets:
@@ -699,7 +714,7 @@ def test_get_definition_list_from_batch_request_with_unnamed_data_asset_name_rai
             config=my_data_connector_yaml,
             runtime_environment={
                 "name": "general_azure_data_connector",
-                "datasource_name": "test_environment",
+                "execution_engine": PandasExecutionEngine(),
             },
             config_defaults={
                 "module_name": "great_expectations.datasource.data_connector"
@@ -713,7 +728,7 @@ def test_get_definition_list_from_batch_request_with_unnamed_data_asset_name_rai
             BatchRequest(
                 datasource_name="test_environment",
                 data_connector_name="general_azure_data_connector",
-                data_asset_name=None,
+                data_asset_name="",
             )
         )
 
@@ -738,8 +753,6 @@ def test_return_all_batch_definitions_unsorted_without_named_data_asset_name(
         f"""
            class_name: ConfiguredAssetAzureDataConnector
            datasource_name: test_environment
-           execution_engine:
-               class_name: PandasExecutionEngine
            container: my_container
            name_starts_with: ""
            assets:
@@ -774,7 +787,7 @@ def test_return_all_batch_definitions_unsorted_without_named_data_asset_name(
             config=my_data_connector_yaml,
             runtime_environment={
                 "name": "general_azure_data_connector",
-                "datasource_name": "test_environment",
+                "execution_engine": PandasExecutionEngine(),
             },
             config_defaults={
                 "module_name": "great_expectations.datasource.data_connector"
@@ -794,7 +807,7 @@ def test_return_all_batch_definitions_unsorted_without_named_data_asset_name(
             BatchRequestBase(
                 datasource_name="test_environment",
                 data_connector_name="general_azure_data_connector",
-                data_asset_name=None,
+                data_asset_name="",
             )
         )
     )
@@ -821,8 +834,6 @@ def test_return_all_batch_definitions_unsorted_with_named_data_asset_name(
         f"""
            class_name: ConfiguredAssetAzureDataConnector
            datasource_name: test_environment
-           execution_engine:
-               class_name: PandasExecutionEngine
            container: my_container
            name_starts_with: ""
            assets:
@@ -857,7 +868,7 @@ def test_return_all_batch_definitions_unsorted_with_named_data_asset_name(
             config=my_data_connector_yaml,
             runtime_environment={
                 "name": "general_azure_data_connector",
-                "datasource_name": "test_environment",
+                "execution_engine": PandasExecutionEngine(),
             },
             config_defaults={
                 "module_name": "great_expectations.datasource.data_connector"
@@ -904,8 +915,6 @@ def test_return_all_batch_definitions_basic_sorted(
         f"""
        class_name: ConfiguredAssetAzureDataConnector
        datasource_name: test_environment
-       execution_engine:
-           class_name: PandasExecutionEngine
        container: my_container
        name_starts_with: ""
        assets:
@@ -951,7 +960,7 @@ def test_return_all_batch_definitions_basic_sorted(
             config=my_data_connector_yaml,
             runtime_environment={
                 "name": "general_azure_data_connector",
-                "datasource_name": "test_environment",
+                "execution_engine": PandasExecutionEngine(),
             },
             config_defaults={
                 "module_name": "great_expectations.datasource.data_connector"
@@ -994,8 +1003,6 @@ def test_return_all_batch_definitions_returns_specified_partition(
         f"""
        class_name: ConfiguredAssetAzureDataConnector
        datasource_name: test_environment
-       execution_engine:
-           class_name: PandasExecutionEngine
        container: my_container
        name_starts_with: ""
        assets:
@@ -1041,7 +1048,7 @@ def test_return_all_batch_definitions_returns_specified_partition(
             config=my_data_connector_yaml,
             runtime_environment={
                 "name": "general_azure_data_connector",
-                "datasource_name": "test_environment",
+                "execution_engine": PandasExecutionEngine(),
             },
             config_defaults={
                 "module_name": "great_expectations.datasource.data_connector"
@@ -1114,8 +1121,6 @@ def test_return_all_batch_definitions_sorted_without_data_connector_query(
         f"""
        class_name: ConfiguredAssetAzureDataConnector
        datasource_name: test_environment
-       execution_engine:
-           class_name: PandasExecutionEngine
        container: my_container
        name_starts_with: ""
        assets:
@@ -1161,7 +1166,7 @@ def test_return_all_batch_definitions_sorted_without_data_connector_query(
             config=my_data_connector_yaml,
             runtime_environment={
                 "name": "general_azure_data_connector",
-                "datasource_name": "test_environment",
+                "execution_engine": PandasExecutionEngine(),
             },
             config_defaults={
                 "module_name": "great_expectations.datasource.data_connector"
@@ -1204,8 +1209,6 @@ def test_return_all_batch_definitions_raises_error_due_to_sorter_that_does_not_m
         f"""
        class_name: ConfiguredAssetAzureDataConnector
        datasource_name: test_environment
-       execution_engine:
-           class_name: PandasExecutionEngine
        container: my_container
        assets:
            TestFiles:
@@ -1255,7 +1258,7 @@ def test_return_all_batch_definitions_raises_error_due_to_sorter_that_does_not_m
             config=my_data_connector_yaml,
             runtime_environment={
                 "name": "general_azure_data_connector",
-                "datasource_name": "test_environment",
+                "execution_engine": PandasExecutionEngine(),
             },
             config_defaults={
                 "module_name": "great_expectations.datasource.data_connector"
@@ -1279,8 +1282,6 @@ def test_return_all_batch_definitions_too_many_sorters(
         f"""
        class_name: ConfiguredAssetAzureDataConnector
        datasource_name: test_environment
-       execution_engine:
-           class_name: PandasExecutionEngine
        container: my_container
        name_starts_with: ""
        assets:
@@ -1326,7 +1327,7 @@ def test_return_all_batch_definitions_too_many_sorters(
             config=my_data_connector_yaml,
             runtime_environment={
                 "name": "general_azure_data_connector",
-                "datasource_name": "test_environment",
+                "execution_engine": PandasExecutionEngine(),
             },
             config_defaults={
                 "module_name": "great_expectations.datasource.data_connector"
@@ -1394,7 +1395,10 @@ azure_options:
             config_defaults={
                 "module_name": "great_expectations.datasource.data_connector"
             },
-            runtime_environment={"name": "my_data_connector"},
+            runtime_environment={
+                "name": "my_data_connector",
+                "execution_engine": PandasExecutionEngine(),
+            },
         )
     )
 
@@ -1530,7 +1534,10 @@ azure_options:
             config_defaults={
                 "module_name": "great_expectations.datasource.data_connector"
             },
-            runtime_environment={"name": "my_data_connector"},
+            runtime_environment={
+                "name": "my_data_connector",
+                "execution_engine": PandasExecutionEngine(),
+            },
         )
     )
 
