@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
 # snapshottest: v1 - https://goo.gl/zC4yUc
-from __future__ import unicode_literals
 
 from snapshottest import Snapshot
 
@@ -521,7 +519,7 @@ snapshots[
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "ignore_row_if": {"schema": {"type": "string"}, "value": "baz"},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": "80"},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "or_equal": {"schema": {"type": "boolean"}, "value": True},
             "parse_strings_as_datetimes": {
                 "schema": {"type": "boolean"},
@@ -550,7 +548,7 @@ snapshots[
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "ignore_row_if": {"schema": {"type": "string"}, "value": "baz"},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": "80"},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "parse_strings_as_datetimes": {
                 "schema": {"type": "boolean"},
                 "value": None,
@@ -720,7 +718,7 @@ snapshots[
             "max_value": {"schema": {"type": "number"}, "value": 20},
             "min_value": {"schema": {"type": "number"}, "value": 10},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": "80"},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "row_condition": {"schema": {"type": "string"}, "value": None},
             "strict_max": {"schema": {"type": "boolean"}, "value": None},
             "strict_min": {"schema": {"type": "boolean"}, "value": None},
@@ -746,6 +744,7 @@ snapshots[
             "max_value": {"schema": {"type": "number"}, "value": 20},
             "min_value": {"schema": {"type": "number"}, "value": 10},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "row_condition": {"schema": {"type": "string"}, "value": None},
             "strict_max": {"schema": {"type": "boolean"}, "value": None},
             "strict_min": {"schema": {"type": "boolean"}, "value": None},
@@ -767,7 +766,7 @@ snapshots["test_atomic_prescriptive_summary_expect_column_value_lengths_to_equal
             "column": {"schema": {"type": "string"}, "value": "my_column"},
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": "80"},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "row_condition": {"schema": {"type": "string"}, "value": None},
             "value": {"schema": {"type": "number"}, "value": 100},
         },
@@ -790,7 +789,7 @@ snapshots["test_atomic_prescriptive_summary_expect_column_values_to_be_between 1
             "max_value": {"schema": {"type": "number"}, "value": 5},
             "min_value": {"schema": {"type": "number"}, "value": 1},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": "80"},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "row_condition": {"schema": {"type": "string"}, "value": None},
             "strict_max": {"schema": {"type": "boolean"}, "value": None},
             "strict_min": {"schema": {"type": "boolean"}, "value": None},
@@ -814,7 +813,7 @@ snapshots[
             "column": {"schema": {"type": "string"}, "value": "my_column"},
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": "80"},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "row_condition": {"schema": {"type": "string"}, "value": None},
         },
         "schema": {"type": "com.superconductive.rendered.string"},
@@ -836,6 +835,7 @@ snapshots[
             "column": {"schema": {"type": "string"}, "value": "my_column"},
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "parse_strings_as_datetimes": {
                 "schema": {"type": "boolean"},
                 "value": True,
@@ -860,7 +860,7 @@ snapshots["test_atomic_prescriptive_summary_expect_column_values_to_be_in_set 1"
             "column": {"schema": {"type": "string"}, "value": "my_column"},
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": "80"},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "parse_strings_as_datetimes": {
                 "schema": {"type": "boolean"},
                 "value": True,
@@ -891,7 +891,7 @@ snapshots[
             "column": {"schema": {"type": "string"}, "value": "my_column"},
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": "80"},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "row_condition": {"schema": {"type": "string"}, "value": None},
             "type_list": {
                 "schema": {"type": "array"},
@@ -920,7 +920,7 @@ snapshots[
             "column": {"schema": {"type": "string"}, "value": "my_column"},
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": "80"},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "parse_strings_as_datetimes": {
                 "schema": {"type": "boolean"},
                 "value": True,
@@ -947,7 +947,7 @@ snapshots[
             "column": {"schema": {"type": "string"}, "value": "my_column"},
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": "80"},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "row_condition": {"schema": {"type": "string"}, "value": None},
         },
         "schema": {"type": "com.superconductive.rendered.string"},
@@ -967,7 +967,7 @@ snapshots["test_atomic_prescriptive_summary_expect_column_values_to_be_null 1"]
             "column": {"schema": {"type": "string"}, "value": "my_column"},
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": "80"},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "row_condition": {"schema": {"type": "string"}, "value": None},
         },
         "schema": {"type": "com.superconductive.rendered.string"},
@@ -987,7 +987,7 @@ snapshots["test_atomic_prescriptive_summary_expect_column_values_to_be_of_type 1
             "column": {"schema": {"type": "string"}, "value": "my_column"},
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": None},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "row_condition": {"schema": {"type": "string"}, "value": None},
             "type_": {"schema": {"type": "string"}, "value": "my_type"},
         },
@@ -1008,7 +1008,7 @@ snapshots["test_atomic_prescriptive_summary_expect_column_values_to_be_unique 1"
             "column": {"schema": {"type": "string"}, "value": "my_column"},
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": "80"},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "row_condition": {"schema": {"type": "string"}, "value": None},
         },
         "schema": {"type": "com.superconductive.rendered.string"},
@@ -1031,7 +1031,7 @@ snapshots[
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "json_schema": {"schema": {"type": "object"}, "value": {"foo": "bar"}},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": "80"},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "row_condition": {"schema": {"type": "string"}, "value": None},
         },
         "schema": {"type": "com.superconductive.rendered.string"},
@@ -1051,7 +1051,7 @@ snapshots["test_atomic_prescriptive_summary_expect_column_values_to_match_regex
             "column": {"schema": {"type": "string"}, "value": "my_column"},
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": "80"},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "regex": {"schema": {"type": "string"}, "value": "^superconductive$"},
             "row_condition": {"schema": {"type": "string"}, "value": None},
         },
@@ -1075,6 +1075,7 @@ snapshots[
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "match_on": {"schema": {"type": "string"}, "value": "all"},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "regex_list": {
                 "schema": {"type": "array"},
                 "value": ["^superconductive$", "ge|great_expectations"],
@@ -1102,7 +1103,7 @@ snapshots[
             "column": {"schema": {"type": "string"}, "value": "my_column"},
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": "80"},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "row_condition": {"schema": {"type": "string"}, "value": None},
             "strftime_format": {"schema": {"type": "string"}, "value": "%Y-%m"},
         },
@@ -1125,7 +1126,7 @@ snapshots[
             "column": {"schema": {"type": "string"}, "value": "my_column"},
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": "80"},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "parse_strings_as_datetimes": {
                 "schema": {"type": "boolean"},
                 "value": None,
@@ -1153,7 +1154,7 @@ snapshots["test_atomic_prescriptive_summary_expect_column_values_to_not_be_null
             "column": {"schema": {"type": "string"}, "value": "my_column"},
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": "80"},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "row_condition": {"schema": {"type": "string"}, "value": None},
         },
         "schema": {"type": "com.superconductive.rendered.string"},
@@ -1175,6 +1176,7 @@ snapshots[
             "column": {"schema": {"type": "string"}, "value": "my_column"},
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "regex": {"schema": {"type": "string"}, "value": "^superconductive$"},
             "row_condition": {"schema": {"type": "string"}, "value": None},
         },
@@ -1197,7 +1199,7 @@ snapshots[
             "column": {"schema": {"type": "string"}, "value": "my_column"},
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": "80"},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "regex_list": {"schema": {"type": "array"}, "value": ["^a", "^b", "^c"]},
             "row_condition": {"schema": {"type": "string"}, "value": None},
             "v__0": {"schema": {"type": "string"}, "value": "^a"},
@@ -1225,7 +1227,7 @@ snapshots["test_atomic_prescriptive_summary_expect_compound_columns_to_be_unique
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "ignore_row_if": {"schema": {"type": "string"}, "value": None},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": "80"},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "row_condition": {"schema": {"type": "string"}, "value": None},
         },
         "schema": {"type": "com.superconductive.rendered.string"},
@@ -1248,7 +1250,7 @@ snapshots[
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "ignore_row_if": {"schema": {"type": "string"}, "value": "foo"},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
-            "mostly_pct": {"schema": {"type": "number"}, "value": "80"},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "row_condition": {"schema": {"type": "string"}, "value": None},
             "v__0": {"schema": {"type": "string"}, "value": "A"},
             "v__1": {"schema": {"type": "string"}, "value": "B"},
@@ -1277,6 +1279,7 @@ snapshots[
             "condition_parser": {"schema": {"type": "string"}, "value": None},
             "ignore_row_if": {"schema": {"type": "string"}, "value": "foo"},
             "mostly": {"schema": {"type": "number"}, "value": 0.8},
+            "mostly_pct": {"schema": {"type": "string"}, "value": "80"},
             "row_condition": {"schema": {"type": "string"}, "value": None},
             "v__0": {"schema": {"type": "string"}, "value": "my_first_column"},
             "v__1": {"schema": {"type": "string"}, "value": "my_second_column"},
