@@ -37,15 +37,15 @@ rules:
       - expectation_type: expect_table_row_count_to_be_between
         class_name: DefaultExpectationConfigurationBuilder
         module_name: great_expectations.rule_based_profiler.expectation_configuration_builder
-        min_value: $parameter.row_count_range.value.value_range[0]
-        max_value: $parameter.row_count_range.value.value_range[1]
+        min_value: $parameter.row_count_range.value[0]
+        max_value: $parameter.row_count_range.value[1]
         mostly: $variables.mostly
         meta:
           profiler_details: $parameter.row_count_range.details
   column_ranges_rule:
     domain_builder:
-      class_name: SimpleSemanticTypeColumnDomainBuilder
-      semantic_types:
+      class_name: ColumnDomainBuilder
+      include_semantic_types:
         - numeric
       # BatchRequest yielding exactly one batch (March, 2019 trip data)
       batch_request:
@@ -84,8 +84,8 @@ rules:
         class_name: DefaultExpectationConfigurationBuilder
         module_name: great_expectations.rule_based_profiler.expectation_configuration_builder
         column: $domain.domain_kwargs.column
-        min_value: $parameter.min_range.value.value_range[0]
-        max_value: $parameter.min_range.value.value_range[1]
+        min_value: $parameter.min_range.value[0]
+        max_value: $parameter.min_range.value[1]
         mostly: $variables.mostly
         meta:
           profiler_details: $parameter.min_range.details
@@ -93,8 +93,8 @@ rules:
         class_name: DefaultExpectationConfigurationBuilder
         module_name: great_expectations.rule_based_profiler.expectation_configuration_builder
         column: $domain.domain_kwargs.column
-        min_value: $parameter.max_range.value.value_range[0]
-        max_value: $parameter.max_range.value.value_range[1]
+        min_value: $parameter.max_range.value[0]
+        max_value: $parameter.max_range.value[1]
         mostly: $variables.mostly
         meta:
           profiler_details: $parameter.max_range.details
