@@ -37,6 +37,9 @@ def expectations():
 # noinspection PyPep8Naming
 @pytest.mark.smoketest
 @pytest.mark.rendered_output
+@pytest.mark.filterwarnings(
+    "ignore:Cannot get %*::great_expectations.render.renderer.profiling_results_overview_section_renderer"
+)
 def test_render_DefaultJinjaPageView_meta_info():
     validation_results = ExpectationSuiteValidationResult(
         **{
