@@ -23,16 +23,15 @@ def test_single_batch_very_few_cardinality(alice_columnar_table_single_batch_con
     )
 
     domain_builder: DomainBuilder = CategoricalColumnDomainBuilder(
+        exclude_column_name_suffixes="_id",
+        limit_mode="very_few",
         batch_request=batch_request,
         data_context=data_context,
-        limit_mode="very_few",
     )
     domains: List[Domain] = domain_builder.get_domains()
 
     alice_all_column_names: List[str] = [
-        "id",
         "event_type",
-        "user_id",
         "event_ts",
         "server_ts",
         "device_ts",
@@ -49,7 +48,7 @@ def test_single_batch_very_few_cardinality(alice_columnar_table_single_batch_con
         )
         for column_name in alice_all_column_names
     ]
-    assert len(domains) == 7
+    assert len(domains) == 5
     assert domains == alice_all_column_domains
 
 
@@ -63,9 +62,9 @@ def test_single_batch_one_cardinality(alice_columnar_table_single_batch_context)
     )
 
     domain_builder: DomainBuilder = CategoricalColumnDomainBuilder(
+        limit_mode="ONE",
         batch_request=batch_request,
         data_context=data_context,
-        limit_mode="ONE",
     )
     domains: List[Domain] = domain_builder.get_domains()
 
@@ -100,9 +99,9 @@ def test_unsupported_cardinality_limit(
 
     with pytest.raises(ProfilerConfigurationError) as excinfo:
         _: List[Domain] = CategoricalColumnDomainBuilder(
+            limit_mode="&*#$&INVALID&*#$*&",
             batch_request=batch_request,
             data_context=data_context,
-            limit_mode="&*#$&INVALID&*#$*&",
         ).get_domains()
 
     assert "specify a supported cardinality mode" in str(excinfo.value)
@@ -123,8 +122,8 @@ def test_unspecified_cardinality_limit(
 
     with pytest.raises(ProfilerConfigurationError) as excinfo:
         _: List[Domain] = CategoricalColumnDomainBuilder(
-            data_context=data_context,
             batch_request=batch_request,
+            data_context=data_context,
         ).get_domains()
 
     assert "Please pass ONE of the following parameters" in str(excinfo.value)
@@ -141,8 +140,6 @@ def test_excluded_columns_single_batch(alice_columnar_table_single_batch_context
     )
 
     domain_builder: DomainBuilder = CategoricalColumnDomainBuilder(
-        batch_request=batch_request,
-        data_context=data_context,
         limit_mode="VERY_FEW",
         exclude_column_names=[
             "id",
@@ -151,6 +148,8 @@ def test_excluded_columns_single_batch(alice_columnar_table_single_batch_context
             "event_ts",
             "server_ts",
         ],
+        batch_request=batch_request,
+        data_context=data_context,
     )
     domains: List[Domain] = domain_builder.get_domains()
 
@@ -183,10 +182,10 @@ def test_excluded_columns_empty_single_batch(alice_columnar_table_single_batch_c
     )
 
     domain_builder: DomainBuilder = CategoricalColumnDomainBuilder(
-        batch_request=batch_request,
-        data_context=data_context,
         limit_mode="VERY_FEW",
         exclude_column_names=[],
+        batch_request=batch_request,
+        data_context=data_context,
     )
     domains: List[Domain] = domain_builder.get_domains()
 
@@ -228,9 +227,9 @@ def test_multi_batch_very_few_cardinality(
     )
 
     domain_builder: DomainBuilder = CategoricalColumnDomainBuilder(
+        limit_mode="very_few",
         batch_request=batch_request,
         data_context=data_context,
-        limit_mode="very_few",
     )
     observed_domains: List[Domain] = domain_builder.get_domains()
 
@@ -303,9 +302,9 @@ def test_multi_batch_one_cardinality(
     )
 
     domain_builder: DomainBuilder = CategoricalColumnDomainBuilder(
+        limit_mode="ONE",
         batch_request=batch_request,
         data_context=data_context,
-        limit_mode="ONE",
     )
     observed_domains: List[Domain] = domain_builder.get_domains()
 
