@@ -6,7 +6,6 @@ from great_expectations import DataContext
 from great_expectations.rule_based_profiler.domain_builder import (
     ColumnDomainBuilder,
     DomainBuilder,
-    SimpleSemanticTypeColumnDomainBuilder,
     TableDomainBuilder,
 )
 from great_expectations.rule_based_profiler.types import (
@@ -26,8 +25,8 @@ def test_table_domain_builder(
     data_context: DataContext = alice_columnar_table_single_batch_context
 
     domain_builder: DomainBuilder = TableDomainBuilder(
-        data_context=data_context,
         batch_request=None,
+        data_context=data_context,
     )
     domains: List[Domain] = domain_builder.get_domains()
 
@@ -74,8 +73,8 @@ def test_column_domain_builder(
     }
 
     domain_builder: DomainBuilder = ColumnDomainBuilder(
-        data_context=data_context,
         batch_request=batch_request,
+        data_context=data_context,
     )
     domains: List[Domain] = domain_builder.get_domains(variables=variables)
 
@@ -134,7 +133,7 @@ def test_column_domain_builder(
 
 
 # noinspection PyPep8Naming
-def test_simple_semantic_type_column_domain_builder(
+def test_column_domain_builder_with_simple_semantic_type_included(
     alice_columnar_table_single_batch_context,
     alice_columnar_table_single_batch,
     column_Age_domain,
@@ -159,12 +158,12 @@ def test_simple_semantic_type_column_domain_builder(
         "data_connector_name": "alice_columnar_table_single_batch_data_connector",
         "data_asset_name": "alice_columnar_table_single_batch_data_asset",
     }
-    domain_builder: DomainBuilder = SimpleSemanticTypeColumnDomainBuilder(
-        data_context=data_context,
-        batch_request=batch_request,
-        semantic_types=[
+    domain_builder: DomainBuilder = ColumnDomainBuilder(
+        include_semantic_types=[
             "numeric",
         ],
+        batch_request=batch_request,
+        data_context=data_context,
     )
     domains: List[Domain] = domain_builder.get_domains(variables=variables)
 
