@@ -228,21 +228,30 @@ def test_simple_date_format_parameter_builder_bobby(
     )
 
     fully_qualified_parameter_name_for_value: str = (
-        "$parameter.my_simple_date_format_string_parameter_builder"
+        "$parameter.my_simple_date_format_string_parameter_builder.value"
     )
-    expected_value: dict = {
-        "value": "%Y-%m-%d %H:%M:%S",
-        "details": {
-            "success_ratio": 1.0,
-            "candidate_strings": candidate_strings,
-        },
-    }
+    expected_value: str = "%Y-%m-%d %H:%M:%S"
 
-    actual_value: dict = get_parameter_value_and_validate_return_type(
+    actual_value: str = get_parameter_value_and_validate_return_type(
         parameter_reference=fully_qualified_parameter_name_for_value,
-        expected_return_type=dict,
+        expected_return_type=str,
         domain=domain,
         parameters={domain.id: parameter_container},
     )
 
     assert actual_value == expected_value
+
+    fully_qualified_parameter_name_for_meta: str = (
+        "$parameter.my_simple_date_format_string_parameter_builder.details"
+    )
+    expected_meta: dict = {
+        "success_ratio": 1.0,
+        "candidate_strings": candidate_strings,
+    }
+    meta: dict = get_parameter_value_and_validate_return_type(
+        parameter_reference=fully_qualified_parameter_name_for_meta,
+        expected_return_type=dict,
+        domain=domain,
+        parameters={domain.id: parameter_container},
+    )
+    assert meta == expected_meta
